@@ -1,6 +1,6 @@
 package Log::Shiras;
 our $AUTHORITY = 'cpan:JANDREW';
-use version 0.77; our $VERSION = version->declare("v0.38.4");
+use version 0.77; our $VERSION = version->declare("v0.40.2");
 use utf8;
 #########1 main pod docs      3#########4#########5#########6#########7#########8#########9
 __END__
@@ -69,7 +69,7 @@ Log::Shiras - A Moose based logging and reporting tool
 			},
 		);
 	###LogSD warn "Getting a Telephone";
-	my $telephone = Log::Shiras::Telephone->new( report => 'run' );# or just '->new'
+	my $telephone = Log::Shiras::Telephone->new( report => 'run' );
 	$telephone->talk( message => 'Hello World 1' );
 	###LogSD warn "message was sent to the report 'run' without sufficient permissions";
 	$telephone->talk( level => 'info', message => 'Hello World 2' );
@@ -101,26 +101,27 @@ Moose found in the western United States (of America).
 
 This is L<one of many loggers|https://metacpan.org/search?q=Log> you can choose from in
 CPAN.  The ultimate goal of this package is to add name-space control to any of your
-programs outputs that you want name-space control of.  As the program stands today there
+programs outputs that you want name-space control of.  As the package stands today there
 are three relevant name-spaces.  First, the file name-space, file name-space is the
 name-space that we apply to specific files (modules or scripts).  The file name-space in
 this package is treated as flat (no heirarchy) and is managed using L<source code filters
 |Log::Shiras::Unhide>.  File name-space filtering is therefore done at compile time with
 no run time changes available.  The second name-space is a run time caller name-space that
-can be adjusted as the program operates.  Run time name-space is applied to the source of the
-output.  Run time name-space is hierarchical and each output source can be assigned a level
-of urgency.  This allows run time name-space filtering to be applied lower in the heirarchy
-and remain in force out in the branch.  Permissions for run time name-space can also change
-during run time.  Finally, there is a destination name-space.  Not all sources will wish to
-call the same destination.  Destination name-space is flat and less flexible but still
-somewhat editable at run time.  To sort of stich the last three concepts together mentally
-I have used terminology associated with the old land line telephone system.  Run time or
-caller name-space is managed through L<telephones|Log::Shiras::Telephone>.  Run time
-permissions are managed through a L<switchboard|Log::Shiras::Switchboard> with switchboard
-operators.  And destinations are called L<reports|Log::Shiras::Switchboard/reports>.  This
-last term does not follow the terminology of the old land lines since communication through
-this package is one direction.  Reports cannot send messages back on the same connection
-that they use to receive information.
+can be adjusted as the program operates.  Caller name-space is applied to the source of the
+output.  The caller namespace also allows for urgency levels to be assigend to each source
+of information.  The caller namespace is hierarchical which allows filtering to be applied
+lower in the hierarchy and remain in force farther out in the branch.  Caller name-space and
+urgency can be changed during run-time.  Finally, there is a destination name-space.  Not all
+sources will wish to call the same destination.  Destination name-space is flat and less flexible
+but still somewhat editable at run time.  Caller name-space, caller urgency levels, and desination
+name-space are all stiched together using permissions.  Permissions can also be changed at
+run-time.  To sort of stich these concepts together mentally I have used terminology associated
+with the old land line telephone system.  Caller name-space is managed through a L<telephone
+|Log::Shiras::Telephone> class.  Permissions are managed through a L<switchboard
+|Log::Shiras::Switchboard> with switchboard operators.  And destinations are called L<reports
+|Log::Shiras::Switchboard/reports>.  This last term does not follow the terminology of the old
+land lines since communication through this package is one direction.  I<Reports cannot send
+messages back on the same connection that they use to receive information.>
 
 All in all this can create a complex name-space landscape.  For this package all name-spaces
 in the run environment are shared and caution should be used to manage uniqueness.  I would
@@ -135,8 +136,9 @@ I borrowed heavily from them when writing this.
 =head1 Differentiation
 
 Why choose this Logger over one of the many other options?  Here are some implementation
-ecisions that I made that may or may not help that decision.  Many if not all exist in
-other loggers.  I don't think they all exist together an any other logger.
+decisions that I made that may or may not help that decision.  Many if not all of these
+elements exist in other loggers.  I don't think they all exist together an any other
+logger.
 
 =head2 Buffer behavior
 
@@ -146,6 +148,11 @@ branches in the code.  A use case for this is when you are recursively parsing s
 but only want to log the actions in the path that yielded results.  This is different than
 a print buffer that always goes to the output but the send is just delayed.
 
+=head2 A wrapper class for messages
+
+L<Log::Shiras::Telephone> is it's own class and can be used to customize how messages
+are sent as well as being more flexible in allowing the format of sent messages.
+
 =head2 L<Log::Shiras::Test2>
 
 A dedicated test module for testing logged messages that will capture messages at
@@ -165,10 +172,10 @@ file is not empty.  It will also manage (or at least warn) on header drift.
 =head2 Custom formatting
 
 I wanted to be able to use method calls and code references when formatting
-'Report' output.  The L<Log::Shiras::Report::MetaMessage> Role for the 'Report' 
-class does just that.   This varies from Log::Log4perl's 'PatternLayout' as it 
-operates on an array ref or hashref rather than a string.  There may be a string 
-formatter in the future since I half wrote one but I talked myself out of it in 
+'Report' output.  The L<Log::Shiras::Report::MetaMessage> Role for the 'Report'
+class does just that.   This varies from Log::Log4perl's 'PatternLayout' as it
+operates on an array ref or hashref rather than a string.  There may be a string
+formatter in the future since I half wrote one but I talked myself out of it in
 favor of an array ref manipulation scheme.
 
 =head2 L<Moose|Moose::Manual>
@@ -186,7 +193,7 @@ later.  See also L<Log::Dispatch>.
 
 Excessive outputs for troubleshooting will overburden code.  Having a source filter
 will allow the code to remain in source control (no retyping of print statements)
-while still not burdening run time operations generally.  See also 
+while still not burdening run time operations generally.  See also
 L<Log::Log4perl::Resurrector>
 
 =head2  Custom urgency levels
