@@ -1,6 +1,6 @@
 package Log::Shiras::Report::CSVFile;
 our $AUTHORITY = 'cpan:JANDREW';
-use version; our $VERSION = version->declare("v0.38.4");
+use version; our $VERSION = version->declare("v0.40.2");
 #~ use lib '../../../';
 #~ use Log::Shiras::Unhide qw( :InternalReporTCSV );
 ###InternalReporTCSV	warn "You uncovered internal logging statements for Log::Shiras::Report::CSV-$VERSION" if !$ENV{hide_warn};
@@ -178,7 +178,7 @@ sub BUILD{
 			$self->_add_headers_to_file( $header_ref );
 		}
 	}
-	
+	#~ confess "Died here";
 	return 1;
 }
 
@@ -227,7 +227,7 @@ sub _open_file{
 	}
 	
 	# Get to the end for add_line (in case you weren't there before)
-	seek( $self->_get_file_handle, 0, SEEK_END);
+	seek( $self->_get_file_handle, 0, SEEK_END) or confess "Can't seek (end) on $file: $!";
 	
 	return 1;
 }
@@ -349,7 +349,7 @@ sub _add_headers_to_file{
 	
 	# Close the original file
 	flock( $original_fh, LOCK_UN );
-	close( $original_fh );
+	close( $original_fh ) or confess "Couldn't close file: $!";
 	###InternalReporTCSV	$switchboard->master_talk( { report => 'log_file', level => 0,
 	###InternalReporTCSV		name_space => 'Log::Shiras::Report::CSVFile::_add_headers_to_file',
 	###InternalReporTCSV		message =>[ "Closed the original file handle" ], } );
